==> apache-camel-3.4.5-src.zip: apache-camel-3.4.5/components/camel-http/src/test/java/org/apache/camel/component/http/HttpClientConfigurerTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.http;

import org.apache.camel.builder.RouteBuilder;
import org.apache.camel.test.junit5.CamelTestSupport;
import org.junit.jupiter.api.Test;

import static org.junit.jupiter.api.Assertions.assertSame;

public class HttpClientConfigurerTest extends CamelTestSupport {
    private HttpClientConfigurer configurer;

    @Test
    public void testHttpClientConfigurer() throws Exception {
        HttpClientConfigurer gotConfigurer = getMandatoryEndpoint("http://www.google.com/search", HttpEndpoint.class).getHttpClientConfigurer();
        assertSame(configurer, gotConfigurer);
    }

    @Override
    protected RouteBuilder createRouteBuilder() throws Exception {
        return new RouteBuilder() {
            public void configure() {
                // add configurer to http component
                configurer = new ProxyHttpClientConfigurer("proxyhost", 80, "http", "user", "password", null, null);
                getContext().getComponent("http", HttpComponent.class).setHttpClientConfigurer(configurer);

                from("direct:start")
                    .to("http://www.google.com/search");
            }
        };
    }
}

==> apache-camel-3.14.8-src.zip: apache-camel-3.14.8/components/camel-http/src/test/java/org/apache/camel/component/http/HttpClientConfigurerTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.http;

import org.apache.camel.builder.RouteBuilder;
import org.apache.camel.test.junit5.CamelTestSupport;
import org.junit.jupiter.api.Test;

import static org.junit.jupiter.api.Assertions.assertSame;

public class HttpClientConfigurerTest extends CamelTestSupport {
    private HttpClientConfigurer configurer;

    @Test
    public void testHttpClientConfigurer() throws Exception {
        HttpClientConfigurer gotConfigurer
                = getMandatoryEndpoint("http://www.google.com/search", HttpEndpoint.class).getHttpClientConfigurer();
        assertSame(configurer, gotConfigurer);
    }

    @Override
    protected RouteBuilder createRouteBuilder() throws Exception {
        return new RouteBuilder() {
            public void configure() {
                // add configurer to http component
                configurer = new ProxyHttpClientConfigurer("proxyhost", 80, "http", "user", "password", null, null);
                getContext().getComponent("http", HttpComponent.class).setHttpClientConfigurer(configurer);

                from("direct:start")
                        .to("http://www.google.com/search");
            }
        };
    }
}
